@@ -1,8 +1,10 @@
 import asyncio
 import logging
 import signal
+import sys
 from typing import Any
 
+from gunicorn.arbiter import Arbiter
 from gunicorn.workers.base import Worker
 
 from uvicorn.config import Config
@@ -30,7 +32,7 @@ class UvicornWorker(Worker):
         logger.setLevel(self.log.access_log.level)
         logger.propagate = False
 
-        config_kwargs = {
+        config_kwargs: dict = {
             "app": None,
             "log_config": None,
             "timeout_keep_alive": self.cfg.keepalive,
@@ -70,11 +72,15 @@ class UvicornWorker(Worker):
         for s in self.SIGNALS:
             signal.signal(s, signal.SIG_DFL)
 
-    def run(self) -> None:
+    async def _serve(self) -> None:
         self.config.app = self.wsgi
         server = Server(config=self.config)
-        loop = asyncio.get_event_loop()
-        loop.run_until_complete(server.serve(sockets=self.sockets))
+        await server.serve(sockets=self.sockets)
+        if not server.started:
+            sys.exit(Arbiter.WORKER_BOOT_ERROR)
+
+    def run(self) -> None:
+        return asyncio.run(self._serve())
 
     async def callback_notify(self) -> None:
         self.notify()
